# djangocms-bootstrap3

Some templates and templatetags to be used with djangoCMS and Bootstrap3

## CHANGELOG
- 0.2.1
  * Add setup.py to MANIFEST file.

- 0.2.0
  * Adopted to Angular-UI-bootstrap version 0.14 and later.
  * Fixed division issue in paginator for Python3.

- 0.1.0
  * Added templatetag ``main_menu_embody_id``.
  * Fixed various Django templates to render the menu.

- 0.0.2 Initial release.
